@@ -393,25 +393,28 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, neg_
 
 
     d_train = lgb.Dataset(X_train, label=y_train, categorical_feature=cat_features, params=dataset_params)
-    d_valid = lgb.Dataset(X_valid, label=y_valid, categorical_feature=cat_features, params=dataset_params)
+    d_valid = lgb.Dataset(X_valid, label=y_valid, categorical_feature=cat_features, params=dataset_params, reference=d_train)
 
     watchlist = [d_train,d_valid]    
+    #watchlist = [d_valid]  
 
     
-    pruning_callback_t = optuna.integration.LightGBMPruningCallback(trial, metric, valid_name="data_train")    
+    #pruning_callback_t = optuna.integration.LightGBMPruningCallback(trial, metric, valid_name="data_train")    
     pruning_callback_v = optuna.integration.LightGBMPruningCallback(trial, metric, valid_name="data_valid")
 
     model = lgb.train(train_params,                 
                       num_boost_round = num_rounds,
                       train_set=d_train,
-                      valid_names = ['data_train','data_valid'],
+                      #valid_names = ['data_train','data_valid'],
+                      valid_names = ['data_valid'],
                       valid_sets=watchlist,
                       feval=lgb_f1_score,
-                      callbacks=[log_evaluation(log),pruning_callback_t,pruning_callback_v,early_stopping(early_stop)]
+                      #callbacks=[log_evaluation(log),pruning_callback_t,pruning_callback_v,early_stopping(early_stop)],
+                      callbacks=[log_evaluation(log),pruning_callback_v,early_stopping(early_stop)]
                      )
     
-    train_best_score = model.best_score['data_train'][metric]
-    valid_best_score = model.best_score['data_valid'][metric]
+    #train_best_score = model.best_score['data_train'][metric]
+    #valid_best_score = model.best_score['data_valid'][metric]
 
     # predictions
     
@@ -449,6 +452,31 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, neg_
     roc_auc_t = roc_auc_score(y_train, y_pred_prob_train) 
     roc_auc = roc_auc_score(y_valid, y_pred_prob_valid) 
     
+    
+    
+    
+    if metric == 'f1':
+        train_best_score = f1_t
+        valid_best_score = f1
+     
+    elif metric == 'precision':
+        train_best_score = precision_t
+        valid_best_score = precision
+   
+    elif metric == 'recall':
+        train_best_score = recall_t
+        valid_best_score = recall
+
+    elif metric == 'average_precision':
+        train_best_score = train_average_precision
+        valid_best_score = valid_average_precision
+        
+    elif metric == 'roc_auc':
+        train_best_score = roc_auc_t
+        valid_best_score = roc_auc
+    
+    
+    
 
     bias = train_best_score - valid_best_score    
  
